==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-panel/plugin-clock/clock_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation>&lt;Yerele bağlı&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation type="vanished">LXQt Saat Ayarları</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>Saat Ayarları</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Zaman</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>&amp;Saniyeyi göster</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>12 saatlik &amp;gösterim biçimi</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>&amp;UTC dilimini kullan</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>Tarih &amp;biçimi</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>Tarihi göster&amp;me</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>Tarihi saatten &amp;önce göster</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>Tarihi saatten sonr&amp;a göster</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>Tarihi saatin a&amp;ltında yeni bir satırda göster</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation>Haftanın ilk günü</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>Yönlendirme</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>Panel dikey olduğunda otomatik yönlendi&amp;r</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="vanished">&amp;Yazı tipi</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="vanished">Yazı Tipi</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Tarih</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation type="vanished">Tarihi gö&amp;ster</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation type="vanished">T&amp;arih biçimi</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation type="vanished">Yazı &amp;Tipi</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation type="vanished">Tarihi &amp;yeni satırda göster</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation type="vanished">&amp;Tema yazıtipini kullan</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation type="vanished">Zaman yazı tipi</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation type="vanished">Tarih yazıtipi</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation type="vanished">Aşırı ince</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="vanished">Hafif</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation type="vanished">Aşırı siyah</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="vanished">Siyah</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">Koyu</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation type="vanished">Yarı koyu</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Eğik</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation>Özel tarih biçimi girin</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation></translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.12.0.orig.tar.xz: lxqt-l10n-0.12.0/lxqt-panel/plugin-clock/clock_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>FirstDayCombo</name>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="49"/>
        <source>&lt;locale based&gt;</source>
        <translation>&lt;Yerele bağlı&gt;</translation>
    </message>
</context>
<context>
    <name>LXQtClock</name>
    <message>
        <location filename="../../../lxqtclock.cpp" line="57"/>
        <source>Date&amp;Time (clock) plugin is deprecated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="58"/>
        <source>The &lt;strong&gt;clock&lt;/strong&gt; plugin is deprecated and will be removed in future version of LXQt. Consider replacing it with &lt;strong&gt;worldclock&lt;/strong&gt;.&lt;br/&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../lxqtclock.cpp" line="60"/>
        <source>don&apos;t show this again</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtClockConfiguration</name>
    <message>
        <source>LXQt Clock Settings</source>
        <translation type="vanished">LXQt Saat Ayarları</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="14"/>
        <source>Clock Settings</source>
        <translation>Saat Ayarları</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="20"/>
        <source>Time</source>
        <translation>Zaman</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="26"/>
        <source>&amp;Show seconds</source>
        <translation>&amp;Saniyeyi göster</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="33"/>
        <source>12 &amp;hour style</source>
        <translation>12 saatlik &amp;gösterim biçimi</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="40"/>
        <source>&amp;Use UTC</source>
        <translation>&amp;UTC dilimini kullan</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="59"/>
        <source>Date &amp;format</source>
        <translation>Tarih &amp;biçimi</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="76"/>
        <source>&amp;Do not show date</source>
        <translation>Tarihi göster&amp;me</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="86"/>
        <source>Show date &amp;before time</source>
        <translation>Tarihi saatten &amp;önce göster</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="93"/>
        <source>Show date &amp;after time</source>
        <translation>Tarihi saatten sonr&amp;a göster</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="100"/>
        <source>Show date below time on new &amp;line</source>
        <translation>Tarihi saatin a&amp;ltında yeni bir satırda göster</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="107"/>
        <source>First day of week in calendar</source>
        <translation>Haftanın ilk günü</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="124"/>
        <source>Orientation</source>
        <translation>Yönlendirme</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="130"/>
        <source>Auto&amp;rotate when the panel is vertical</source>
        <translation>Panel dikey olduğunda otomatik yönlendi&amp;r</translation>
    </message>
    <message>
        <source>&amp;Font</source>
        <translation type="vanished">&amp;Yazı tipi</translation>
    </message>
    <message>
        <source>Font</source>
        <translation type="vanished">Yazı Tipi</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.ui" line="50"/>
        <source>Date</source>
        <translation>Tarih</translation>
    </message>
    <message>
        <source>Show &amp;date</source>
        <translation type="vanished">Tarihi gö&amp;ster</translation>
    </message>
    <message>
        <source>D&amp;ate format</source>
        <translation type="vanished">T&amp;arih biçimi</translation>
    </message>
    <message>
        <source>Fon&amp;t</source>
        <translation type="vanished">Yazı &amp;Tipi</translation>
    </message>
    <message>
        <source>Show date in &amp;new line</source>
        <translation type="vanished">Tarihi &amp;yeni satırda göster</translation>
    </message>
    <message>
        <source>&amp;Use theme fonts</source>
        <translation type="vanished">&amp;Tema yazıtipini kullan</translation>
    </message>
    <message>
        <source>Time font</source>
        <translation type="vanished">Zaman yazı tipi</translation>
    </message>
    <message>
        <source>Date font</source>
        <translation type="vanished">Tarih yazıtipi</translation>
    </message>
    <message>
        <source>Ultra light</source>
        <translation type="vanished">Aşırı ince</translation>
    </message>
    <message>
        <source>Light</source>
        <translation type="vanished">Hafif</translation>
    </message>
    <message>
        <source>Ultra black</source>
        <translation type="vanished">Aşırı siyah</translation>
    </message>
    <message>
        <source>Black</source>
        <translation type="vanished">Siyah</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation type="vanished">Koyu</translation>
    </message>
    <message>
        <source>Demi bold</source>
        <translation type="vanished">Yarı koyu</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Eğik</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Input custom date format</source>
        <translation>Özel tarih biçimi girin</translation>
    </message>
    <message>
        <location filename="../../../lxqtclockconfiguration.cpp" line="268"/>
        <source>Interpreted sequences of date format are:

d	the day as number without a leading zero (1 to 31)
dd	the day as number with a leading zero (01 to 31)
ddd	the abbreviated localized day name (e.g. &apos;Mon&apos; to &apos;Sun&apos;).
dddd	the long localized day name (e.g. &apos;Monday&apos; to &apos;Sunday&apos;).
M	the month as number without a leading zero (1-12)
MM	the month as number with a leading zero (01-12)
MMM	the abbreviated localized month name (e.g. &apos;Jan&apos; to &apos;Dec&apos;).
MMMM	the long localized month name (e.g. &apos;January&apos; to &apos;December&apos;).
yy	the year as two digit number (00-99)
yyyy	the year as four digit number

All other input characters will be treated as text.
Any sequence of characters that are enclosed in single quotes (&apos;)
will also be treated as text and not be used as an expression.


Custom date format:</source>
        <translation></translation>
    </message>
</context>
</TS>
